import 'package:account/account_errcode.dart';
import 'package:flutter/services.dart';

import 'account.dart' as base_account;
import 'account.dart';

class Account implements base_account.Account {
  final MethodChannel platform;
  const Account(): platform = const MethodChannel("flutter_base/account_plugin");

  @override
  Future<String> getA2() async{
    String a2 = await platform.invokeMethod("getA2");
    return a2;
  }

  @override
  Future<String> getUid() async{
    return await platform.invokeMethod("getUid");
  }

  @override
  Future<bool> isLogin() async{
    try {
      String uid = await platform.invokeMethod("getUid");
      if (uid == "0") {
        return false;
      } else {
        return true;
      }
    }on PlatformException catch (e) {
      print('${e.message}');
      return false;
    } on MissingPluginException catch (e) {
      print('${e.message}');
      return false;
    }
  }

  @override
  Future<int> login(LoginTicketInfo info) async{
    try {
      int errCode = await platform.invokeMethod("loginWithAuth", <String, dynamic>{
        "loginType": info.loginType,
      });

      if (errCode == 200) {
        return AccountErrcode.Success;
      } else if (errCode == -200) {
        return AccountErrcode.Login_ing;
      } else {
        return AccountErrcode.Failed;
      }
    }on PlatformException catch (e) {
      print('${e.message}');
      return AccountErrcode.PlatformException;
    } on MissingPluginException catch (e) {
      print('${e.message}');
      return AccountErrcode.MissPluginException;
    }
  }

  @override
  Future<void> logout() async{
    try {
      await platform.invokeMethod("logout");
    }on PlatformException catch (e) {
      print('${e.message}');
    } on MissingPluginException catch (e) {
      print('${e.message}');
    }
  }

  @override
  Future<int> getLoginStatus() async{
    try {
      return await platform.invokeMethod("getLoginStatus");
    }on PlatformException catch (e) {
      print('${e.message}');
      return AccountErrcode.PlatformException;
    } on MissingPluginException catch (e) {
      print('${e.message}');
      return AccountErrcode.MissPluginException;
    }
  }

  @override
  Future<Map> getLoginInfo() async{
    try {
      return await platform.invokeMethod("getLoginInfo");
    }on PlatformException catch (e) {
      print('${e.message}');
      return null;
    } on MissingPluginException catch (e) {
      print('${e.message}');
      return null;
    }
  }

  @override
  Future<Map> getPhoneCheckCode(String phone) async{
    try {
      return await platform.invokeMethod("getPhoneCheckCode", {
        'phone': phone
      });
    }on PlatformException catch (e) {
      print('${e.message}');
      return null;
    } on MissingPluginException catch (e) {
      print('${e.message}');
      return null;
    }
  }

  @override
  Future<Map> loginWithPhone(String phone, String checkCode) async{
    try {
      return await platform.invokeMethod("loginWithPhone", {
        'phone':phone,
        'code': checkCode
      });
    }on PlatformException catch (e) {
      print('${e.message}');
      return null;
    } on MissingPluginException catch (e) {
      print('${e.message}');
      return null;
    }
  }

  @override
  Future<int> cancelLogin() async{
    try {
      return await platform.invokeMethod("cancelLogin");
    }on PlatformException catch (e) {
      print('${e.message}');
      return -100;
    } on MissingPluginException catch (e) {
      print('${e.message}');
      return -101;
    }
  }
}
